@@ -1,12 +1,11 @@
-
 ###################################################################################################
 #' Minimization by Differential Evolution
-#' 
+#'
 #' For minimization, this function uses the \code{"DEoptim"} method from the
 #' code{DEoptim} package. It is basically a wrapper, to enable DEoptim for usage
 #' in SPOT.
 #'
-#' @param x optional start point, not used in DEoptim
+#' @param x optional start point
 #' @param fun objective function, which receives a matrix x and returns observations y
 #' @param lower boundary of the search space
 #' @param upper boundary of the search space
@@ -29,31 +28,77 @@
 #' @examples
 #' res <- optimDE(,lower = c(-10,-20),upper=c(20,8),fun = funSphere)
 #' res$ybest
+#' optimDE(x = matrix(rep(1,6), 3, 2),lower = c(-10,-20),upper=c(20,8),fun = funSphere, 
+#'    control = list(funEvals=100, populationSize=20))
+#' #Compare to DEoptim:
+#' require(DEoptim)
+#' set.seed(1234)
+#' DEoptim(function(x){funRosen(matrix(x,1))}, lower=c(-10,-10), upper=c(10,10), 
+#'   DEoptim.control(strategy = 2,bs = FALSE, N = 20, itermax = 28, CR = 0.7, F = 1.2,
+#'   trace = FALSE, p = 0.2, c = 0, reltol = sqrt(.Machine$double.eps), steptol = 200 ))
+#' set.seed(1234)
+#' optimDE(, fun=funRosen, lower=c(-10,-10), upper= c(10,10), 
+#'    control = list( populationSize = 20, funEvals = 580, F = 1.2, CR = 0.7))
 #' @export
 ###################################################################################################
-optimDE<-function(x=NULL,fun,lower,upper,control=list(),...){
-  con<-list(funEvals=200,populationSize= (10 * length(lower)),trace=0)
+optimDE <- function(x = NULL,
+                    fun,
+                    lower,
+                    upper,
+                    control = list(),
+                    ...) {
+  con <-
+    list(
+      funEvals = 200,
+      populationSize = (10 * length(lower)),
+      strategy = 2,
+      bs = FALSE,
+      NP = 10,
+      itermax = 100,
+      CR = 0.5,
+      F = 0.8,
+      trace = FALSE,
+      initialpop = NULL,
+      ## storepopfrom
+      #storepopfreq = 1,
+      p = 0.2,
+      c = 0
+    )
   con[names(control)] <- control
-  control<-con
+  control <- con
   funEvals <- control$funEvals
   NP <- control$populationSize
-	
+  
   ## recalculate funEvals to DE iteration on basis of population size
   itermax <- floor((funEvals - NP) / NP)
-  if(itermax < 1) itermax= 1
-	
+  if (itermax < 1)
+    itermax = 1
+  
   control$NP <- control$populationSize
   control$itermax <- itermax
-	
-	## Delete unused settings
+  
+  ## Delete unused settings
   control$populationSize <- NULL
   control$funEvals <- NULL
   control$types <- NULL
-	
+  
   ## wrapper for matrix inputs to fun
-  fn <- function(x,...)fun(matrix(x,1),...) 
-
+  fn <- function(x, ...)
+    fun(matrix(x, 1), ...)
+  
   ## start optim
-  res <- DEoptim(fn=fn,lower=lower,upper=upper,control=control,...)
-  list(x=res$member$bestmemit,y=res$member$bestvalit,xbest=matrix(res$optim$bestmem,1),ybest=matrix(res$optim$bestval,1),count= res$optim$nfeval*nrow(res$member$pop))
+  res <- DEoptim(
+    fn = fn,
+    lower = lower,
+    upper = upper,
+    control = control,
+    ...
+  )
+  list(
+    x = res$member$bestmemit,
+    y = res$member$bestvalit,
+    xbest = matrix(res$optim$bestmem, 1),
+    ybest = matrix(res$optim$bestval, 1),
+    count = res$optim$nfeval * nrow(res$member$pop)
+  )
 }
\ No newline at end of file
