@@ -28,11 +28,11 @@
 #' @examples
 #' ## Most simple example: Kriging + LHS + predicted 
 #' ## mean optimization (not expected improvement)
-#' res <- spot(,funSphere,c(-2,-3),c(1,2))
+#' res <- spot(,funSphere,c(-2,-3),c(1,2),control=list(funEvals=15))
 #' res$xbest
 #' ## With expected improvement
 #' res <- spot(,funSphere,c(-2,-3),c(1,2),
-#'    control=list(modelControl=list(target="ei"))) 
+#'    control=list(funEvals=15,modelControl=list(target="ei"))) 
 #' res$xbest
 #' ### With additional start point:
 #' #res <- spot(matrix(c(0.05,0.1),1,2),funSphere,c(-2,-3),c(1,2))
@@ -41,7 +41,7 @@
 #' #res <- spot(,funSphere,c(-2,-3),c(1,2),
 #' #    control=list(funEvals=50)) 
 #' #res$xbest
-#' ### Use a local optimizer instead of LHS
+#' ### Use local optimization instead of LHS
 #' #res <- spot(,funSphere,c(-2,-3),c(1,2),
 #' #    control=list(optimizer=optimLBFGSB)) 
 #' #res$xbest
@@ -113,15 +113,8 @@ spot <- function(x=NULL,fun, #mostly, fun must have format y=f(x,...).
     
 	## default settings
 	dimension <- length(lower)
-	con <- spotControl(dimension)
-	con[names(control)] <- control
-	control <- con
-	rm(con)
-
-	## All functions should deal with the same data types 
-	control$designControl$types <- control$types
-	control$modelControl$types <- control$types
-	control$optimizerControl$types <- control$types
+	
+	control <- spotFillControlList(control, dimension)
 	
 	## Initial design generation
 	set.seed(control$seedSPOT)
@@ -137,6 +130,29 @@ spot <- function(x=NULL,fun, #mostly, fun must have format y=f(x,...).
 	result
 } 
 
+###################################################################################################
+#' Fill in some values for the control list. Internal use only.
+#'
+#' @param controlList list of controls, see \code{\link{spotControl}}.
+#' @param dimension dimension of the optimization problem. See \code{\link{spotControl}}.
+#' @return a list
+#' @export
+#' @keywords internal
+###################################################################################################
+spotFillControlList <- function(controlList, dimension){
+    con <- spotControl(dimension)
+    con[names(controlList)] <- controlList
+    controlList <- con
+    rm(con)
+    
+    ## All functions should deal with the same data types 
+    controlList$designControl$types <- controlList$types
+    controlList$modelControl$types <- controlList$types
+    controlList$optimizerControl$types <- controlList$types
+    
+    return(controlList)
+}
+
 ###################################################################################################
 #' Default Control list for spot 
 #'
@@ -156,7 +172,7 @@ spot <- function(x=NULL,fun, #mostly, fun must have format y=f(x,...).
 #'				See help of the respective function for details.Default is an empty \code{list}.}
 #'   \item{\code{optimizer}}{A function that is used to optimize based on \code{model}, finding the most promising 
 #'				candidate solutions. Functions that accept the same parameters, and return a matrix like \code{\link{optimLHD}} 
-#'				or \code{\link{optimLBFGSB}} can be used. Default is \code{\link{optimLHD}}.}
+#'				or \code{\link{optimDE}} can be used. Default is \code{\link{optimLHD}}.}
 #'   \item{\code{optimizerControl}}{A list of controls passed to the \code{control} list of the \code{optimizer} function. 
 #'				See help of the respective function for details. Default is an empty \code{list}.}
 #'   \item{\code{noise}}{Boolean, whether the objective function has noise or not. Default is non-noisy, that is, \code{FALSE}.}
@@ -183,6 +199,7 @@ spot <- function(x=NULL,fun, #mostly, fun must have format y=f(x,...).
 #'				for convergence, or for a problem with the configuration.
 #'				In case of noise, duplicates are allowed.}
 #'   \item{\code{plots}}{Whether progress should be tracked by a line plot, default is false}
+#'   \item{\code{infillCriterion}}{A function defining an infillCriterion to be used while optimizing a model. Default: NULL. For example check infillExpectedImprovement}
 #' }
 #' @param dimension dimensionality of the problem, that is, the number of optimzed parameters.
 #' @return a list
@@ -206,7 +223,7 @@ list(
     replicates=1, #the number of replications for all "new" solutions (unless generated by the initial design, which handles them separately)
 		noise= FALSE, #whether or not the target function is non-deterministic. 
 		seedFun = NA, #start RNG seed for the target function (only important if non-deterministic, i.e., if noise==TRUE). NA means that seed is not set before running fun, this is important for cases where an initial seed for the target function is undesirable. (e.g., functions with constant and identical number of calls to random number generator)
-		seedSPOT =1 #start RNG seed for the SPOT loop 
+		seedSPOT =1, #start RNG seed for the SPOT loop 
 	  ## Note: in case of optimization algorithm tuning, where the optimization algorithm again solves 
 		## a noisy objective function, the user should handle proper random number generator seeds for the 
 		## noisy objective function.
@@ -217,6 +234,7 @@ list(
 		## (e.g., based on OCBA). The model itself should handle repeated samples.
     ## The exception from this rule should be if noise==FALSE, in that case, duplicates are removed.
 		## (?) TODO -> what if only one duplicate suggested -> will be suggested again in next iteration?
+	infillCriterion = NULL ## By default no infillCriterion is used
   )
 }
 
@@ -281,7 +299,7 @@ spotLoop <- function(x,y,fun,lower,upper,control,...){
     modelFit <- control$model(x=x,y=y,control=control$modelControl) #todo return modelControl to allow memory?
 		
 		## Generate a surrogate target function from the model
-		funSurrogate <- evaluateModel(modelFit)
+		funSurrogate <- evaluateModel(modelFit, control$infillCriterion)
 		
 		## Model optimization
     optimRes <- control$optimizer(,funSurrogate,lower,upper,control$optimizerControl) #todo return optimizerControl to allow memory?
