@@ -1,7 +1,7 @@
 library(testthat)
 library(SPOT)
 
-options(spot.run.full.test = F)
+options(spot.run.full.test = TRUE)
 
 test_check("SPOT")
 
